@@ -12,7 +12,10 @@ treedat$data4[c(3,4,6,7)] <- c(0.5,1,-3,1)
 treedat$data5[c(3,4,6,7)] <- c(2,0,1,-2)
 
 tree <- with(treedat,ouchtree(node,anc,time))
-htree <- hansen(data=treedat[c("data1","data2")],tree,regimes=treedat["reg"],alpha=c(1,0,1),sigma=c(0.1,0,0.1),fit=F)
+x <- treedat[c(6,4,5,7,3,2,1),c("data1","data2")]
+btree <- brown(data=x,tree)
+print(btree)
+htree <- hansen(data=x,tree,regimes=treedat["reg"],alpha=c(1,0,1),sigma=c(0.1,0,0.1),fit=F)
 print(htree)
 htree <- update(htree,alpha=c(1,-0.1,1),sigma=c(0.5,0.5,1),fit=F)
 print(htree)
